#!/usr/bin/env python

import subprocess
import sys
import os
import click
import webbrowser
import shutil
from hyperdiv.core.utils import strip_path_suffix


@click.group()
def cli():
    """Hyperdiv command-line utility."""


@cli.command("docs")
def docs():
    """Open the Hyperdiv documentation."""
    docs_app_location = os.path.join(
        strip_path_suffix(__file__, 2),
        "docs",
        "main.py",
    )

    if not os.path.isfile(docs_app_location):
        docs_app_location = os.path.join(
            strip_path_suffix(__file__, 3),
            "docs",
            "main.py",
        )

    if not os.path.isfile(docs_app_location):
        print("ERROR: Cannot find the docs app :(")
        sys.exit(1)

    python = shutil.which("python3")
    if not python:
        python = shutil.which("python")

    if not python:
        print("ERROR: Cannot find python3 or python")
        sys.exit(1)

    port = os.getenv("HD_PORT", 8977)
    process = subprocess.Popen(
        [python, docs_app_location],
        env=dict(HD_PORT=str(port)),
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
    )
    print(process.stdout.readline().decode(), end="")
    webbrowser.open(f"http://localhost:{port}")
    process.communicate()


if __name__ == "__main__":
    cli()
