from .. import elements as el


def checkbox(*label, **props):
    """
    The `checkbox` component renders a checkbox component with a
    label.

    ```py
    cb = hd.checkbox("Bunnies")
    if cb.checked:
        hd.text("🐇🐇🐇🐇🐇")
    ```

    Disabled state:

    ```py
    cb = hd.checkbox("Check Me", disabled=True)
    if hd.button("Toggle disabled").clicked:
        cb.disabled = not cb.disabled

    """
    with el.container(direction="horizontal", gap=2, align="start"):
        cb = el.checkbox(*label, **props)

        if cb.valid or not cb.edited:
            cb.checkbox_color = el.theme().primary_color
            cb.font_color = None
            cb.background_color = None
        else:
            cb.checkbox_color = el.theme().error_color
            cb.background_color = el.lighten(el.theme().error_color, 130)
            cb.font_color = el.theme().error_color

        if cb.required:
            el.text("*", font_color=el.theme().error_color)

    return cb
