from nose.tools import assert_raises
from ...core.unittests import simple_test
from ..charts import line_chart, bar_chart, chart, scatter_chart, TooltipProp, AxisProp


@simple_test
def test_line_chart(ctx):
    lc = line_chart((1, 2, 3), series_names=("corn", "cheese", "dog"))
    assert lc.data == ((1, 2, 3),)
    assert lc.x_axis == "category"
    assert lc.series_names == ("corn", "cheese", "dog")


@simple_test
def test_bar_chart(ctx):
    bc = bar_chart((1, 2, 3), series_names=("corn", "cheese", "dog"))
    assert bc.data == ((1, 2, 3),)


@simple_test
def test_scatter_chart(ctx):
    sc = scatter_chart(((1, 3), (2, 4), (5, 6)))
    assert sc.x_axis == "category"


@simple_test
def test_chart(ctx):
    assert_raises(
        ValueError,
        chart,
        (1, 2, 3),
        chart_type="cheese",
        x_axis="category",
    )
    assert_raises(
        ValueError,
        chart,
        (1, 2, 3),
        chart_type="scatter",
        x_axis="value",
        y_axis="value",
    )

    bc = chart("bar", (1, 2, 3), x_axis="category", rotate=True)
    assert bc.rotate


def test_parse_axis():
    prop = AxisProp(None)

    assert prop.parse(None) == dict(show=False)
    assert prop.parse("time") == dict(type="time", splitLine=dict(show=False))
    assert prop.parse((1, 3)) == dict(
        type="category", data=(1, 3), splitLine=dict(show=False)
    )
    assert_raises(ValueError, prop.parse, "bunnies")


def test_parse_tooltip():
    prop = TooltipProp(None)

    assert prop.parse(None) is None
    assert prop.parse("axis") == dict(trigger="axis")
    assert_raises(ValueError, prop.parse, "bunnies")
