from nose.tools import assert_raises
from ...core.unittests import simple_test
from ..radio_group import radio_group
from ...elements.form import form
from ...elements.radio import radio


@simple_test
def test_radio_group(ctx):
    rg = radio_group(
        "Food",
        "corn",
        ("cheese", "corn", "dog"),
        disabled=("cheese", "corn"),
    )
    assert rg.value == "corn"
    assert rg.disabled == ("cheese", "corn")
    assert rg.is_empty is False

    rg = radio_group(
        "Food",
        "corn",
        ("cheese", "corn", "dog"),
        disabled="dog",
    )
    assert rg.disabled == "dog"

    # Test duplicate values
    assert_raises(ValueError, radio_group, "Food", "corn", ("corn", "corn"))

    # Test selecting invalid option
    def set_invalid():
        rg.selected = "bunnies"

    assert_raises(ValueError, set_invalid)

    # Test resetting
    rg.selected = "dog"

    assert rg.selected == "dog"
    assert rg.edited is True

    rg.reset()

    assert rg.selected == "corn"
    assert rg.edited is False

    # Test that resetting a child resets the group
    with form() as f:
        rg = radio_group("Food", "corn", ("corn", "beef"))

    rg.selected = "corn"
    assert rg.edited

    assert len(f._inputs) == 2
    assert isinstance(f._inputs[0], radio)
    f._inputs[0].reset()

    assert rg.selected == "corn"
    assert not rg.edited
