from .text_utils import markdown_with_code_examples


def markdown():
    markdown_with_code_examples(
        '''
        # Text & Markdown

        Hyperdiv has full markdown support in the
        [text](/components/text) component, and parses it with the
        popular Python
        [Markdown](https://github.com/Python-Markdown/markdown)
        library. A lot of the text in this documentation app is
        structured using the [text](/components/text) component with
        markdown syntax.

        A description of the markdown syntax supported by Hyperdiv can
        be found
        [here](https://daringfireball.net/projects/markdown/syntax).

        Here are some examples of what you can do with markdown:

        ```py
        hd.text("""
            # Title
            ## Subtitle

            A list:

            * One
            * Two
            * Three

            A separator:

            ---

            [A Link](https://hyperdiv.io)

            <div style="color:green">
               And you can embed HTML, too.
            </div>
        """)
        ```

        You could make your own abstractions that format data with
        markdown. For example, here's how to make a list abstraction
        that takes a title and a list of items and outputs a formatted
        list, either bulleted or numbered:

        ```py
        def my_list(title, items, numbered=False):
            hd.text(title)
            if numbered:
                items = "\\n".join([
                    f"{i}. {item}" for i, item in enumerate(items)
                ])
            else:
                items = "\\n".join([f"* {item}" for item in items])
            hd.text(items)

        with hd.box(gap=8):
            my_list(
                "Groceries:", 
                ["Bacon", "Lettuce", "Tomatoes"]
            )
            my_list(
                "Forms of Transportation:",
                ["Cars", "Bikes", "Planes", "Boats"],
                numbered=True
            )
        ```

        ## Gotcha: Indentation

        When rendering multi-line markdown, beware of doing this:

        ```py
        hd.text(
            """My list:

            * Foo
            * Bar
            """
        )
        ```

        Notice that the markdown list isn't rendered properly. This is
        because the indentation level of the first line (0) does not
        match the indentation level of the subsequent lines (4). The
        correct way to specify this markdown:

        ```py
        hd.text(
            """
            My list:

            * Foo
            * Bar
            """
        )
        ```
        '''
    )
