import inspect
import hyperdiv as hd
from .table_utils import cell_style, header_row, qualname


def collect_methods(klass):
    # List of (class, [methods]) sorted by distance in the inheritance
    # hierarchy
    method_map = []
    tag = "[public]"

    def collect(klass):
        if klass in {k for (k, _) in method_map}:
            return

        methods = []
        for k, v in vars(klass).items():
            if (
                (callable(v) or (type(v) is property and v.fget))
                and v.__doc__
                and v.__doc__.strip().startswith(tag)
            ):
                # TODO: more detailed handling of properties, because
                # they don't behave like methods
                if type(v) is property:
                    v = v.fget

                methods.append((v, v.__doc__.strip()[len(tag) :]))
        if len(methods) > 0:
            method_map.append((klass, methods))

        for b in klass.__bases__:
            collect(b)

    if not inspect.isclass(klass):
        return method_map

    collect(klass)
    return method_map


def method_tables(element_function_name):
    from inspect import signature

    element = eval(f"hd.{element_function_name}")
    method_map = collect_methods(element)

    if len(method_map) == 0:
        return

    with hd.box(gap=8):
        hd.text("### Methods")

        with hd.table():
            with hd.table_body():
                for klass, fns in method_map:
                    with hd.scope(qualname(klass)):
                        if klass != element:
                            with hd.table_row():
                                with hd.table_cell(
                                    colspan=4,
                                    padding=(16, 8, 8, 0),
                                    border=None,
                                ):
                                    hd.text("#### Inherited from", klass.__name__)
                        header_row("Name", "Signature", "Description")
                        for fn, doc in fns:
                            with hd.scope(qualname(fn)):
                                sig = signature(fn)
                                with hd.table_row():
                                    hd.table_cell(fn.__name__, **cell_style)
                                    hd.table_cell(
                                        f"`{fn.__name__}{str(sig)}`", **cell_style
                                    )
                                    hd.table_cell(doc, **cell_style)
