from .text_utils import markdown_with_code_examples


def modals():
    markdown_with_code_examples(
        """
        # Modals

        Hyperdiv provides several *modal* boxes that can be used for
        user alerts, to implement menus that slide in and out of the
        document (drawers) or contextual data that slides from the
        bottom or top.

        Modals do not interfere with the flow of the document, and
        appear strictly *above* the document.

        ## Dialogs

        ```py
        d = hd.dialog("Alert!", buttons=["Dismiss"])
        with d.content():
            hd.text("Hello, this is an alert.")
            hd.text("Arbitrary components can go in here.")

        if hd.button("Open Alert").clicked:
            d.opened = True
        ```

        ## Drawers

        ```py
        with hd.box(gap=16):
            position = hd.radio_group(
                "Drawer Position",
                "left",
                ("left", "right")
            )

            drawer = hd.drawer(position=position.value)

            with drawer.content():
                hd.text("Hello, this is a drawer.")
                hd.text("Arbitrary components can go in here.")

            if hd.button("Open Drawer").clicked:
                drawer.opened = True
        ```

        ## Trays

        ```py
        with hd.box(gap=16):
            position = hd.radio_group(
                "Tray Position",
                "bottom",
                ("bottom", "top")
            )

            tray = hd.tray(position=position.value)

            with tray.content():
                hd.text("Hello, this is a tray.")
                hd.text("Arbitrary components can go in here.")

            if hd.button("Open Tray").clicked:
                tray.opened = True
        ```

        """
    )
