from textwrap import dedent as dedent_text
import hyperdiv as hd


def parse_doc(doc):
    chunks = []
    current_chunk = None
    lines = dedent_text(doc).split("\n")

    def process_current_chunk():
        if current_chunk and current_chunk["content"]:
            chunks.append(current_chunk)

    for line in lines:
        if line.strip().startswith("```py"):
            process_current_chunk()
            current_chunk = dict(type="code", content="")
            continue
        elif (
            line.strip().startswith("```")
            and current_chunk
            and current_chunk["type"] == "code"
        ):
            process_current_chunk()
            current_chunk = dict(type="text", content="")
            continue
        if not current_chunk:
            current_chunk = dict(type="text", content="")
        current_chunk["content"] += line + "\n"

    process_current_chunk()

    return chunks


def code_example(code):
    with hd.hbox(gap=16):
        with hd.box(width="50%", horizontal_scroll=True):
            hd.code(code, height="100%")
        with hd.box(
            width="50%",
            height="100%",
        ):
            try:
                exec(dedent_text(code))
            except Exception as e:
                hd.text(f"`Error: {e}`", font_color=hd.theme().red)


def render_doc_chunks(doc_chunks):
    with hd.box(gap=16):
        for i, doc_chunk in enumerate(doc_chunks):
            with hd.scope(i):
                if doc_chunk["type"] == "text":
                    hd.text(doc_chunk["content"])
                elif doc_chunk["type"] == "code":
                    code_example(doc_chunk["content"])


def markdown_with_code_examples(doc):
    return render_doc_chunks(parse_doc(doc))
