from .theme import theme_prop
from .label_element import LabelElement
from .props import (
    BoolProp,
    OptionalStrProp,
    PaddingProp,
    FontWeightProp,
    FontSizeProp,
    OutlineProp,
    SizeProp,
    ColorProp,
    BorderProp,
    CursorProp,
)
from .prop_utils import highlight


class button(LabelElement):
    """
    The `button` component renders a clickable button with a label.

    Example:

    ```py
    s = hd.state(count=0)
    if hd.button("Click Me").clicked:
      s.count += 1
    hd.text("You clicked", s.count, "times")
    ```
    """

    disabled = BoolProp(False)
    role = OptionalStrProp(None)

    # Override StyledElement
    background_color = theme_prop("primary_color")

    hover_background_color = ColorProp(lambda b: highlight(b.background_color))
    active_background_color = ColorProp(lambda b: highlight(b.hover_background_color))

    border_radius = theme_prop("border_radius")
    border = BorderProp(
        lambda b: (
            # No top border:
            None,
            # No right border:
            None,
            # Bottom border:
            (3, "solid", highlight(b.background_color)),
        )
    )
    padding = PaddingProp(8)
    font_family = theme_prop("font_family")
    font_color = ColorProp("#fff")

    font_weight = FontWeightProp("bold")
    font_size = FontSizeProp("medium")
    cursor = CursorProp("pointer")
    focus_outline = OutlineProp("auto")

    width = SizeProp("fit-content")
