import html
from textwrap import dedent as dedent_text
from ..core.element import RemoveProp
from .styled_element import StyledElement
from .label_element import label_join
from .props import OptionProp, BoolProp, StrProp


class CodeProp(StrProp):
    def parse(self, value):
        value = super().parse(value).rstrip()
        while len(value) > 0 and value[0] == "\n":
            value = value[1:]
        return html.escape(dedent_text(value))


class code(StyledElement):
    '''
    The `code` component is used to render blocks of syntax-highlighted
    code. In fact, this is the same component used to render the code
    blocks in this documentation.

    ```py
    hd.code("""
    def add(a, b):
        return a + b
    """)
    hd.code(
        "const add = (a, b) => a + b;",
        language="javascript",
        border="blue",
        height=100,
        padding=32,
        active_background_color="green"
    )
    ```
    '''

    code = CodeProp("")
    language = OptionProp(
        "python",
        # TODO: support all languages supported by Prism
        ("python", "css", "markup", "clike", "javascript"),
    )
    show_line_numbers = BoolProp(False)

    # Override style props
    font_color = RemoveProp()
    background_color = RemoveProp()

    def args_to_props(self, *args, **kwargs):
        if args:
            kwargs["code"] = label_join(args)
        return kwargs
