from ..core.element import RemoveProp
from .input_element import Prop
from .styled_element import StyledElement
from .prop_utils import parse_color
from .props import SizeProp


class ChartOptionsProp(Prop):
    def parse(self, options):
        if type(options) != dict:
            raise ValueError("echart options must be a dict.")

        if "color" in options:
            color = options["color"]
            if isinstance(color, str):
                options["color"] = parse_color(color)
            elif type(color) in (list, tuple):
                options["color"] = [parse_color[val] for val in color]
            elif isinstance(color, dict) and "seeds" in color:
                # color can be dict(auto="true", seeds=[...])
                # which will auto generate the chart values using the provided seeds
                # as points along a gradient
                color["seeds"] = [parse_color(val) for val in color["seeds"]]

        return options


class echart(StyledElement):
    """
    Renders an echart with the specified options.
    https://echarts.apache.org/en/option.html
    """

    options = ChartOptionsProp(dict())
    data_clicked = Prop(None, is_event_prop=True)

    # Override StyledElement
    min_width = SizeProp(50)
    min_height = SizeProp(50)
    height = SizeProp(180)

    cursor = RemoveProp()
    font_size = RemoveProp()
