from ..core.element import Element, Prop
from .props import OutlineProp, BoolProp


class FormInput(Element):
    # We set `value` to a super generic Prop(None) just to have
    # something, since reset() and edited() refer to this prop. Each
    # subclass is expected to define its own `value` prop with
    # specific type.
    value = Prop(None)
    disabled = BoolProp(False)
    valid = BoolProp(True)
    required = BoolProp(False)
    focus_outline = OutlineProp("auto")

    @property
    def edited(self):
        return self.mutated("value")

    @property
    def is_empty(self):
        return not self.value

    def reset(self):
        self.reset_prop("value")
        self.reset_prop("valid")
