from .theme import theme
from .styled_element import StyledElement
from .props import Prop, FontFamilyProp, FontSizeProp
from .prop_utils import highlight


def get_json_tree_style(e):
    t = theme()

    text_color = highlight(t.white if t.is_dark else t.black)

    # svelte-json-tree is controlled using these CSS variables.
    return {
        "--json-tree-string-color": t.red,
        "--json-tree-symbol-color": t.red,
        "--json-tree-boolean-color": t.blue,
        "--json-tree-function-color": t.blue,
        "--json-tree-number-color": t.blue,
        "--json-tree-label-color": t.green,
        "--json-tree-property-color": text_color,
        "--json-tree-arrow-color": text_color,
        "--json-tree-operator-color": text_color,
        "--json-tree-null-color": text_color,
        "--json-tree-undefined-color": text_color,
        "--json-tree-date-color": text_color,
        "--json-tree-internal-color": text_color,
        "--json-tree-regex-color": t.blue,
        "--json-tree-font-family": e.font_family,
        "--json-tree-font-size": e.font_size,
    }


class json(StyledElement):
    """The `json` component renders a json-serializable object nicely,
    allowing users to collapse/expand and explore the json
    structure. The `json` component is implemented using
    [svelte-json-tree](https://github.com/tanhauhau/svelte-json-tree).

    Example:

    ```py
    hd.json(dict(users=[
        dict(id=1, name="Mark", age=25),
        dict(id=2, name="Steve", age=34, interests=["Reading", "Hiking"])
    ]))
    ```
    """

    json = Prop(None)
    json_tree_style = Prop(get_json_tree_style)
    font_family = FontFamilyProp("Monaco, Courier")
    font_size = FontSizeProp("small")

    def args_to_props(self, *args, **kwargs):
        if args:
            if len(args) > 1:
                raise ValueError(
                    "json takes at most 1 positional argument: the json object"
                )
            kwargs["json"] = args[0]
        return kwargs
