from nose.tools import assert_raises
from ...core.unittests import simple_test
from .. import prop_utils as pu
from ..theme import theme


@simple_test
def test_color_utils(ctx):
    assert pu.is_hex_color("#a1b1c1") is True
    assert pu.is_hex_color("#abc") is True
    assert pu.is_hex_color("#aabbcc12") is True

    assert pu.is_hex_color("foo") is False
    assert pu.is_hex_color("#12") is False
    assert pu.is_hex_color("#abz") is False

    assert pu.is_theme_color("#123") is False
    assert pu.is_theme_color("red") is True
    assert pu.is_theme_color("blue") is True
    assert pu.is_theme_color("bunnies") is False

    assert pu.theme_color_from_str("red") == theme().red
    assert pu.theme_color_from_str("blue") == theme().blue
    assert pu.theme_color_from_str("bunnies") is None

    assert pu.is_color("#abc") is True
    assert pu.is_color("#12z") is False
    assert pu.is_color("red") is True
    assert pu.is_color("blue") is True
    assert pu.is_color("bunnies") is False

    assert pu.parse_color("#123") == "#123"
    assert pu.parse_color("red") == theme().red
    assert_raises(ValueError, pu.parse_color, "bunnies")
    assert_raises(ValueError, pu.parse_color, "#1234")
    assert_raises(ValueError, pu.parse_color, "#ffbbzz")

    assert pu.to_rgba("#123") == (17, 34, 51, 255)
    assert pu.to_rgba("#11223309") == (17, 34, 51, 9)
    assert pu.to_rgba("red") == pu.to_rgba(theme().red)
    assert_raises(ValueError, pu.to_rgba, "beef")
    assert_raises(ValueError, pu.to_rgba, "#1234")

    assert pu.is_light(pu.to_rgba("#abc"))
    assert not pu.is_light(pu.to_rgba("#123"))

    assert pu.offset_color((0, 0, 0, 0), 9) == "#09090900"
    assert pu.offset_color((255, 255, 255, 0), 9) == "#ffffff00"

    assert pu.highlight("#111") == pu.lighten("#111")
    assert pu.highlight("#abc") == pu.darken("#abc")

    assert pu.is_url("https://google.com")
    assert pu.is_url("http://google.com")
    assert not pu.is_url("https://")
    assert not pu.is_url("http://")
    assert not pu.is_url("foo")
    assert not pu.is_url(0)
    assert not pu.is_url(object())
