from .icon import Icons, inline_icon_html
from .label_element import LabelElement, LabelProp
from markdown import markdown as parse_markdown
from textwrap import dedent as dedent_text


def parse_hd_markdown(markdown_str):
    markdown_str = dedent_text(markdown_str)
    return parse_markdown(markdown_str, extensions=["fenced_code"])


class MarkdownProp(LabelProp):
    def parse(self, value):
        return parse_hd_markdown(value)


class text(LabelElement):
    # Override label prop to parse the value as markdown
    label = MarkdownProp("")

    # Identify icons in the args and convert to html
    # and escape any given HTML
    def args_to_props(self, *args, **kwargs):
        if len(args) > 0:
            args = list(args)
            for index, arg in enumerate(args):
                if isinstance(arg, Icons):
                    args[index] = inline_icon_html(arg)
        return super().args_to_props(*args, **kwargs)


def link(url, name=None):
    if name is None:
        name = url
    return text(f'<a href="{url}">{name}</a>')


def anchor(name):
    return text(f'<a name="{name}"></a>')
